tlslite.utils.openssl_tripledes.OpenSSL_TripleDES

Package tlslite :: Package utils :: Module openssl_tripledes :: Class OpenSSL_TripleDES |
[hide private]
[frames] | no frames]

# Class OpenSSL_TripleDES

source code

    tripledes.TripleDES --+
                          |
                         OpenSSL_TripleDES

Instance Methods | [hide private]
__init__(self, key, mode, IV) | source code
_createContext(self, encrypt) | source code
decrypt(self, ciphertext) | source code
encrypt(self, plaintext) | source code

Method Details | [hide private]

### __init__(self, key, mode, IV) (Constructor) | source code
Overrides: tripledes.TripleDES.__init__

### decrypt(self, ciphertext) | source code
Overrides: tripledes.TripleDES.decrypt

### encrypt(self, plaintext) | source code
Overrides: tripledes.TripleDES.encrypt